@@ -10,19 +10,17 @@ Puppet::Type.type(:ironic_config).provide(
   end
 
   def to_project_uuid(name)
-    warning('to_project_uuid is deprecated and will be removed in a future release.')
     properties = [name, '--column', 'id']
-    openstack = Puppet::Provider::Ironic::OpenstackRequest.new
-    res = openstack.openstack_request('project', 'show', properties)
+    ironic_provider = Puppet::Provider::Ironic
+    res = ironic_provider.system_request('project', 'show', properties)
     return "AUTH_#{res[:id]}"
   end
 
   def from_project_uuid(uuid)
-    warning('from_project_uuid is deprecated and will be removed in a future release.')
     uuid = uuid.sub('AUTH_','')
     properties = [uuid, '--column', 'name']
-    openstack = Puppet::Provider::Ironic::OpenstackRequest.new
-    res = openstack.openstack_request('project', 'show', properties)
-    return "AUTH_#{res[:name]}"
+    ironic_provider = Puppet::Provider::Ironic
+    res = ironic_provider.system_request('project', 'show', properties)
+    return res[:name]
   end
 end
