@@ -54,10 +54,7 @@ describe 'ironic::db' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld',
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_behaves_like 'ironic::db'
