@@ -17,29 +17,17 @@ require 'spec_helper'
 
 describe 'ironic::inspector::ironic' do
 
-  let :default_params do
-    { :auth_type      => 'password',
-      :auth_url       => 'http://127.0.0.1:5000/v3',
-      :project_name   => 'services',
-      :username       => 'ironic',
-    }
-  end
-
   let :params do
-    {}
+    { :password => 'secret' }
   end
 
   shared_examples_for 'ironic-inspector ironic configuration' do
-    let :p do
-      default_params.merge(params)
-    end
-
     it 'configures ironic.conf' do
-      is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value(p[:auth_type])
-      is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:auth_url])
-      is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value(p[:project_name])
-      is_expected.to contain_ironic_inspector_config('ironic/username').with_value(p[:username])
-      is_expected.to contain_ironic_inspector_config('ironic/password').with_value('<SERVICE DEFAULT>').with_secret(true)
+      is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value('password')
+      is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value('http://127.0.0.1:5000')
+      is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value('services')
+      is_expected.to contain_ironic_inspector_config('ironic/username').with_value('ironic')
+      is_expected.to contain_ironic_inspector_config('ironic/password').with_value('secret').with_secret(true)
       is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('ironic/system_scope').with_value('<SERVICE DEFAULT>')
@@ -56,7 +44,6 @@ describe 'ironic::inspector::ironic' do
           :auth_url            => 'http://example.com',
           :project_name        => 'project1',
           :username            => 'admin',
-          :password            => 'pa$$w0rd',
           :user_domain_name    => 'NonDefault',
           :project_domain_name => 'NonDefault',
           :region_name         => 'regionTwo',
@@ -67,18 +54,17 @@ describe 'ironic::inspector::ironic' do
       end
 
       it 'should replace default parameter with new value' do
-        is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value(p[:auth_type])
-        is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:auth_url])
-        is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value(p[:project_name])
-        is_expected.to contain_ironic_inspector_config('ironic/username').with_value(p[:username])
-        is_expected.to contain_ironic_inspector_config('ironic/password').with_value(p[:password]).with_secret(true)
-        is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value(p[:user_domain_name])
-        is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value(p[:project_domain_name])
+        is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value(params[:auth_type])
+        is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(params[:auth_url])
+        is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value(params[:project_name])
+        is_expected.to contain_ironic_inspector_config('ironic/username').with_value(params[:username])
+        is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value(params[:user_domain_name])
+        is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value(params[:project_domain_name])
         is_expected.to contain_ironic_inspector_config('ironic/system_scope').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_inspector_config('ironic/region_name').with_value(p[:region_name])
-        is_expected.to contain_ironic_inspector_config('ironic/endpoint_override').with_value(p[:endpoint_override])
-        is_expected.to contain_ironic_inspector_config('ironic/max_retries').with_value(p[:max_retries])
-        is_expected.to contain_ironic_inspector_config('ironic/retry_interval').with_value(p[:retry_interval])
+        is_expected.to contain_ironic_inspector_config('ironic/region_name').with_value(params[:region_name])
+        is_expected.to contain_ironic_inspector_config('ironic/endpoint_override').with_value(params[:endpoint_override])
+        is_expected.to contain_ironic_inspector_config('ironic/max_retries').with_value(params[:max_retries])
+        is_expected.to contain_ironic_inspector_config('ironic/retry_interval').with_value(params[:retry_interval])
       end
     end
 
