@@ -17,28 +17,17 @@ require 'spec_helper'
 
 describe 'ironic::inspector::swift' do
 
-  let :default_params do
-    { :auth_type    => 'password',
-      :project_name => 'services',
-      :username     => 'ironic',
-    }
-  end
-
   let :params do
-    {}
+    { :password => 'secret' }
   end
 
   shared_examples_for 'ironic-inspector swift configuration' do
-    let :p do
-      default_params.merge(params)
-    end
-
     it 'configures ironic-inspector.conf' do
-      is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value(p[:auth_type])
-      is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_inspector_config('swift/project_name').with_value(p[:project_name])
-      is_expected.to contain_ironic_inspector_config('swift/username').with_value(p[:username])
-      is_expected.to contain_ironic_inspector_config('swift/password').with_value('<SERVICE DEFAULT>').with_secret(true)
+      is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value('password')
+      is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value('http://127.0.0.1:5000')
+      is_expected.to contain_ironic_inspector_config('swift/project_name').with_value('services')
+      is_expected.to contain_ironic_inspector_config('swift/username').with_value('ironic')
+      is_expected.to contain_ironic_inspector_config('swift/password').with_value('secret').with_secret(true)
       is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('swift/region_name').with_value('<SERVICE DEFAULT>')
@@ -55,7 +44,6 @@ describe 'ironic::inspector::swift' do
           :auth_url            => 'http://example.com',
           :project_name        => 'project1',
           :username            => 'admin',
-          :password            => 'pa$$w0rd',
           :user_domain_name    => 'NonDefault',
           :project_domain_name => 'NonDefault',
           :region_name         => 'regionTwo',
@@ -66,17 +54,16 @@ describe 'ironic::inspector::swift' do
       end
 
       it 'should replace default parameter with new value' do
-        is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value(p[:auth_type])
-        is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(p[:auth_url])
-        is_expected.to contain_ironic_inspector_config('swift/project_name').with_value(p[:project_name])
-        is_expected.to contain_ironic_inspector_config('swift/username').with_value(p[:username])
-        is_expected.to contain_ironic_inspector_config('swift/password').with_value(p[:password]).with_secret(true)
-        is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value(p[:user_domain_name])
-        is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value(p[:project_domain_name])
-        is_expected.to contain_ironic_inspector_config('swift/region_name').with_value(p[:region_name])
+        is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value(params[:auth_type])
+        is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(params[:auth_url])
+        is_expected.to contain_ironic_inspector_config('swift/project_name').with_value(params[:project_name])
+        is_expected.to contain_ironic_inspector_config('swift/username').with_value(params[:username])
+        is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value(params[:user_domain_name])
+        is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value(params[:project_domain_name])
+        is_expected.to contain_ironic_inspector_config('swift/region_name').with_value(params[:region_name])
         is_expected.to contain_ironic_inspector_config('swift/system_scope').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_ironic_inspector_config('swift/endpoint_override').with_value(p[:endpoint_override])
-        is_expected.to contain_ironic_inspector_config('swift/container').with_value(p[:container])
+        is_expected.to contain_ironic_inspector_config('swift/endpoint_override').with_value(params[:endpoint_override])
+        is_expected.to contain_ironic_inspector_config('swift/container').with_value(params[:container])
         is_expected.to contain_ironic_inspector_config('swift/delete_after').with_value(0)
       end
     end
