@@ -40,6 +40,8 @@ describe 'ironic::keystone::auth' do
         :email               => 'ironic@localhost',
         :tenant              => 'services',
         :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:6385',
         :internal_url        => 'http://127.0.0.1:6385',
         :admin_url           => 'http://127.0.0.1:6385',
@@ -53,6 +55,8 @@ describe 'ironic::keystone::auth' do
           :email               => 'alt_ironic@alt_localhost',
           :tenant              => 'alt_service',
           :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
@@ -78,6 +82,8 @@ describe 'ironic::keystone::auth' do
         :email               => 'alt_ironic@alt_localhost',
         :tenant              => 'alt_service',
         :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
